### Name: gsubfn
### Title: Pattern Matching and Replacement
### Aliases: gsubfn
### Keywords: character

### ** Examples

# adds 1 to each number in third arg
gsubfn("[[:digit:]]+", ~ as.numeric(x)+1, "(10 20)(100 30)") 

# replaces pairs m:n with their sum
g <- function(z,x,y) as.numeric(x)+as.numeric(y)
gsubfn("([0-9]+):([0-9]+)", g, "abc 10:20 def 30:40 50")

# same - can reduce args in function to two using backref = -2
f <- function(x,y) as.numeric(x)+as.numeric(y)
gsubfn("([0-9]+):([0-9]+)", f, "abc 10:20 def 30:40 50", backref = -2)

# same but uses formula in place of function
gsubfn("([0-9]+):([0-9]+)", ~ as.numeric(x) + as.numeric(y), backref = -2,
        "abc 10:20 def 30:40 50")

gsubfn( , , "pi = $pi, 2pi = `2*pi`") 

# Extracts numbers from string and places them into numeric vector v.
# Also see ?strapply
v <- c(); f <- function(x) v <<- append(v,as.numeric(x))
junk <- gsubfn("[0-9]+", f, "12;34:56,89,,12")
v

# makes all letters except first in word lower case
gsubfn("\\B.", tolower, "I LIKE A BANANA SPLIT")

# replaces numbers with that many Xs
repx <- function(n) paste(rep("X", n), collapse = "") 
gsubfn("[[:digit:]]+", repx, "5.2")

# given number followed by SI scale letter (e.g. 32.5k where k means 1000)
# replace letter with E followed by appropriate digit (3 in this example).
# conv vector is from formatEng2R by Hans-Joerg Bibiko (see R wiki)
conv <- paste0("E", c(seq(-24 ,-3, by=3), -1, -2, seq(3, 24, by=3)))
names(conv) <- c("y","z","a","f","p","n",
                   "","m","d","c","k","M","G","T","P","E","Z","Y")
gsubfn(".$", function(x) conv[[x]], "32.5k")  # "32.5E3"




